window.Gleam.initSearch([{"doc":"parser_gleam","title":"parser_gleam","content":"# parser_gleam\n\n[![Package Version](https://img.shields.io/hexpm/v/parser_gleam)](https://hex.pm/packages/parser_gleam)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/parser_gleam/)\n\nA porting of [parser-ts](https://github.com/gcanti/parser-ts), [purescript-eulalie](https://github.com/bodil/purescript-eulalie) to Gleam\n\n## Usage\n\ngleam_parser works on the principle of constructing parsers from smaller\nparsers using various combinator functions.\n\nA parser is a function which takes an input `Stream`, and returns a\n`ParseResult` value which can be either a success or an error.\n\nThe type of parsers is defined like this:\n\n```gleam\npub type Parser(i, a) =\n  fn(Stream(i)) -&gt; ParseResult(i, a)\n```\n\n### Data Types\n\n```gleam\npub type Stream(a) {\n  Stream(buffer: List(a), cursor: Int)\n}\n```\n\nA `Stream` just contains an list of input data, and an index into\nthis list. While many `Stream`s will be created during a parse operation,\nwe only ever keep a single copy of the list they wrap.\n\n```gleam\npub type ParseResult(i, a) =\n  Result(ParseSuccess(i, a), ParseError(i))\n```\n\nA `ParseResult` is what&#39;s returned from a parser, and signals whether\nit succeeded or failed. It wraps one of two result values,\n`ParseSuccess` and `ParseError`.\n\n```gleam\npub type ParseSuccess(i, a) {\n  ParseSuccess(value: a, next: Stream(i), start: Stream(i))\n}\n```\n\nA `ParseSuccess` contains three properties: the `value` we parsed (an\narbitrary value), the `next` input to be parsed (a `Stream`) and the\npoint in the stream where we `start`ed parsing (also a `Stream`).\n\n```gleam\npub type ParseError(i) {\n  ParseError(input: Stream(i), expected: List(String), fatal: Bool)\n}\n```\n\nFinally, a `ParseError` simply contains an `input` property (a\n`Stream`) which points to the exact position where the parsing failed,\nand a set of string descriptions of expected inputs. It also contains\na `fatal` flag, which signifies to the `either` combinator that we\nshould stop parsing immediately instead of trying further parsers.\n\n### Parser Combinators\n\nThe most basic parsers form the building blocks from which you can\nassemble more complex parsers:\n\n- `fn succeed(a) -&gt; Parser(i, a)` makes a parser which\n  doesn&#39;t consume input, just returns the provided value wrapped in\n  a `ParseSuccess`.\n- `fn fail() -&gt; Parser(i, a)` is a parser which consumes no\n  input and returns a `ParseError`.\n- `fn item() -&gt; Parser(i, i)` is a parser which consumes one\n  arbitrary input value and returns it as a `ParseSuccess`.\n\nThe two fundamental parser combinators are:\n\n- `seq(fa: Parser(i, a), f: fn(a) -&gt; Parser(i, b))` is used to combine multiple parsers in a sequence. It takes a\n  parser, and a function which will be called with the result of the\n  parser if it succeeded, and must return another parser, which will\n  be run on the remaining input. The result of the combined parser\n  will be the result of this last parser, or the first error\n  encountered.\n\n- `either(p: Parser(i, a), f: fn() -&gt; Parser(i, a)) -&gt; Parser(i, a)`\n  makes a parser which will first try the first provided parser, and\n  returns its result if it succeeds. If it fails, it will run the\n  second parser on the same input, and return its result directly,\n  whether or not it succeeded.\n\n  If you&#39;ve heard the term &quot;backtracking&quot; in relation to parsers,\n  this is handled automatically by the `either` function, and you\n  don&#39;t need to worry about it.\n\nUsing these, you can construct more advanced parser combinators. Some particularly useful combinators are predefined:\n\n- `sat(predicate: Predicate(i)) -&gt; Parser(i, i)` makes a parser\n  which will match one input value only if the provided predicate\n  function returns `true` for it.\n- `many(p: Parser(i, a)) -&gt; Parser(i, List(a))` makes a\n  parser which will match the provided parser zero or more times.\n- `many1(parser: Parser(i, a)) -&gt; Parser(i, NonEmptyList(a))` works just\n  like `many`, but requires at minimum one match.\n- `char(c: Char) -&gt; Parser(Char, Char)` makes a parser which matches a\n  specific single character.\n- `string(s: String) -&gt; Parser(Char, String)` makes a parser which\n  matches the provided string exactly.\n\nOther predefined parsers are `digit`, `space`, `alphanum`, `letter`,\n`upper` and `lower`, which match one character of their respective\ntypes, and their inverse counterparts, `notDigit`, `notSpace`,\n`notAlphanum`, `notLetter`, `notUpper` and `notLower`. There are also\nwhitespace matchers `spaces` and `spaces1`, and their opposites,\n`notSpaces` and `notSpaces1`.\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add parser_gleam\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/parser_gleam&gt;.\n","url":"index.html"},{"doc":"parser_gleam/stream","title":"ItAndNext","content":"pub type ItAndNext(a) {\n  ItAndNext(value: a, next: Stream(a))\n}\n\nItAndNext(value: a, next: Stream(a))\n\n\nSynonyms:\nparser_gleam/stream.ItAndNext\nparser_gleam/stream ItAndNext","url":"parser_gleam/stream.html#ItAndNext"},{"doc":"parser_gleam/stream","title":"Stream","content":"pub type Stream(a) {\n  Stream(buffer: List(a), cursor: Int)\n}\n\nStream(buffer: List(a), cursor: Int)\n\n\nSynonyms:\nparser_gleam/stream.Stream\nparser_gleam/stream Stream","url":"parser_gleam/stream.html#Stream"},{"doc":"parser_gleam/stream","title":"at_end","content":"pub fn at_end(s: Stream(a)) -&gt; Bool\n\nSynonyms:\nparser_gleam/stream.at_end\nparser_gleam/stream at_end","url":"parser_gleam/stream.html#at_end"},{"doc":"parser_gleam/stream","title":"get","content":"pub fn get(s: Stream(a)) -&gt; Option(a)\n\nSynonyms:\nparser_gleam/stream.get\nparser_gleam/stream get","url":"parser_gleam/stream.html#get"},{"doc":"parser_gleam/stream","title":"get_and_next","content":"pub fn get_and_next(s: Stream(a)) -&gt; Option(ItAndNext(a))\n\nSynonyms:\nparser_gleam/stream.get_and_next\nparser_gleam/stream get_and_next","url":"parser_gleam/stream.html#get_and_next"},{"doc":"parser_gleam/stream","title":"get_eq","content":"pub fn get_eq(e: Eq(a)) -&gt; Eq(Stream(a))\n\nSynonyms:\nparser_gleam/stream.get_eq\nparser_gleam/stream get_eq","url":"parser_gleam/stream.html#get_eq"},{"doc":"parser_gleam/stream","title":"stream","content":"pub fn stream(buffer: List(a), cursor: Option(Int)) -&gt; Stream(a)\n\nSynonyms:\nparser_gleam/stream.stream\nparser_gleam/stream stream","url":"parser_gleam/stream.html#stream"},{"doc":"parser_gleam/stream","title":"parser_gleam/stream","content":"","url":"parser_gleam/stream.html"},{"doc":"parser_gleam/parse_result","title":"ParseError","content":"pub type ParseError(i) {\n  ParseError(\n    input: Stream(i),\n    expected: List(String),\n    fatal: Bool,\n  )\n}\n\nParseError(input: Stream(i), expected: List(String), fatal: Bool)\n\n\nSynonyms:\nparser_gleam/parse_result.ParseError\nparser_gleam/parse_result ParseError","url":"parser_gleam/parse_result.html#ParseError"},{"doc":"parser_gleam/parse_result","title":"ParseResult","content":"pub type ParseResult(i, a) =\n  Result(ParseSuccess(i, a), ParseError(i))\n\n\nSynonyms:\nparser_gleam/parse_result.ParseResult\nparser_gleam/parse_result ParseResult","url":"parser_gleam/parse_result.html#ParseResult"},{"doc":"parser_gleam/parse_result","title":"ParseSuccess","content":"pub type ParseSuccess(i, a) {\n  ParseSuccess(value: a, next: Stream(i), start: Stream(i))\n}\n\nParseSuccess(value: a, next: Stream(i), start: Stream(i))\n\n\nSynonyms:\nparser_gleam/parse_result.ParseSuccess\nparser_gleam/parse_result ParseSuccess","url":"parser_gleam/parse_result.html#ParseSuccess"},{"doc":"parser_gleam/parse_result","title":"error","content":"pub fn error(input: Stream(a), expected: Option(List(String)), fatal: Option(\n    Bool,\n  )) -&gt; Result(ParseSuccess(a, b), ParseError(a))\n\nSynonyms:\nparser_gleam/parse_result.error\nparser_gleam/parse_result error","url":"parser_gleam/parse_result.html#error"},{"doc":"parser_gleam/parse_result","title":"escalate","content":"pub fn escalate(err: ParseError(a)) -&gt; ParseError(a)\n\nSynonyms:\nparser_gleam/parse_result.escalate\nparser_gleam/parse_result escalate","url":"parser_gleam/parse_result.html#escalate"},{"doc":"parser_gleam/parse_result","title":"extend","content":"pub fn extend(err1: ParseError(a), err2: ParseError(a)) -&gt; ParseError(\n  a,\n)\n\nSynonyms:\nparser_gleam/parse_result.extend\nparser_gleam/parse_result extend","url":"parser_gleam/parse_result.html#extend"},{"doc":"parser_gleam/parse_result","title":"success","content":"pub fn success(value: a, next: Stream(b), start: Stream(b)) -&gt; Result(\n  ParseSuccess(b, a),\n  ParseError(b),\n)\n\nSynonyms:\nparser_gleam/parse_result.success\nparser_gleam/parse_result success","url":"parser_gleam/parse_result.html#success"},{"doc":"parser_gleam/parse_result","title":"with_expected","content":"pub fn with_expected(err: ParseError(a), expected: List(String)) -&gt; ParseError(\n  a,\n)\n\nSynonyms:\nparser_gleam/parse_result.with_expected\nparser_gleam/parse_result with_expected","url":"parser_gleam/parse_result.html#with_expected"},{"doc":"parser_gleam/parse_result","title":"parser_gleam/parse_result","content":"","url":"parser_gleam/parse_result.html"},{"doc":"parser_gleam/parser","title":"Parser","content":"pub type Parser(i, a) =\n  fn(Stream(i)) -&gt; ParseResult(i, a)\n\n\nSynonyms:\nparser_gleam/parser.Parser\nparser_gleam/parser Parser","url":"parser_gleam/parser.html#Parser"},{"doc":"parser_gleam/parser","title":"alt","content":"pub fn alt(fa: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a)), that: fn() -&gt;\n    fn(Stream(a)) -&gt; Result(ParseSuccess(a, b), ParseError(a))) -&gt; fn(\n  Stream(a),\n) -&gt; Result(ParseSuccess(a, b), ParseError(a))\n\nSynonyms:\nparser_gleam/parser.alt\nparser_gleam/parser alt","url":"parser_gleam/parser.html#alt"},{"doc":"parser_gleam/parser","title":"ap","content":"pub fn ap(mab: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, fn(b) -&gt; c), ParseError(a)), ma: fn(\n    Stream(a),\n  ) -&gt; Result(ParseSuccess(a, b), ParseError(a))) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, c), ParseError(a))\n\nSynonyms:\nparser_gleam/parser.ap\nparser_gleam/parser ap","url":"parser_gleam/parser.html#ap"},{"doc":"parser_gleam/parser","title":"ap_first","content":"pub fn ap_first(fb: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a))) -&gt; fn(\n  fn(Stream(a)) -&gt; Result(ParseSuccess(a, c), ParseError(a)),\n) -&gt; fn(Stream(a)) -&gt; Result(ParseSuccess(a, c), ParseError(a))\n\nSynonyms:\nparser_gleam/parser.ap_first\nparser_gleam/parser ap_first","url":"parser_gleam/parser.html#ap_first"},{"doc":"parser_gleam/parser","title":"ap_second","content":"pub fn ap_second(fb: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a))) -&gt; fn(\n  fn(Stream(a)) -&gt; Result(ParseSuccess(a, c), ParseError(a)),\n) -&gt; fn(Stream(a)) -&gt; Result(ParseSuccess(a, b), ParseError(a))\n\nSynonyms:\nparser_gleam/parser.ap_second\nparser_gleam/parser ap_second","url":"parser_gleam/parser.html#ap_second"},{"doc":"parser_gleam/parser","title":"between","content":"pub fn between(left: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a)), right: fn(\n    Stream(a),\n  ) -&gt; Result(ParseSuccess(a, b), ParseError(a))) -&gt; fn(\n  fn(Stream(a)) -&gt; Result(ParseSuccess(a, c), ParseError(a)),\n) -&gt; fn(Stream(a)) -&gt; Result(ParseSuccess(a, c), ParseError(a))\n Matches the provided parser `p` that occurs between the provided `left` and `right` parsers.\n\n `p` is polymorphic in its return type, because in general bounds and actual parser could return different types.\nSynonyms:\nparser_gleam/parser.between\nparser_gleam/parser between","url":"parser_gleam/parser.html#between"},{"doc":"parser_gleam/parser","title":"chain","content":"pub fn chain(ma: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a)), f: fn(b) -&gt;\n    fn(Stream(a)) -&gt; Result(ParseSuccess(a, c), ParseError(a))) -&gt; fn(\n  Stream(a),\n) -&gt; Result(ParseSuccess(a, c), ParseError(a))\n\nSynonyms:\nparser_gleam/parser.chain\nparser_gleam/parser chain","url":"parser_gleam/parser.html#chain"},{"doc":"parser_gleam/parser","title":"chain_first","content":"pub fn chain_first(ma: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a)), f: fn(b) -&gt;\n    fn(Stream(a)) -&gt; Result(ParseSuccess(a, c), ParseError(a))) -&gt; fn(\n  Stream(a),\n) -&gt; Result(ParseSuccess(a, b), ParseError(a))\n\nSynonyms:\nparser_gleam/parser.chain_first\nparser_gleam/parser chain_first","url":"parser_gleam/parser.html#chain_first"},{"doc":"parser_gleam/parser","title":"chain_rec","content":"pub fn chain_rec(a: a, f: fn(a) -&gt;\n    fn(Stream(b)) -&gt;\n      Result(ParseSuccess(b, Result(c, a)), ParseError(b))) -&gt; fn(\n  Stream(b),\n) -&gt; Result(ParseSuccess(b, c), ParseError(b))\n\nSynonyms:\nparser_gleam/parser.chain_rec\nparser_gleam/parser chain_rec","url":"parser_gleam/parser.html#chain_rec"},{"doc":"parser_gleam/parser","title":"cut","content":"pub fn cut(p: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a))) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, b), ParseError(a))\n The `cut` parser combinator takes a parser and produces a new parser for\n which all errors are fatal, causing either to stop trying further\n parsers and return immediately with a fatal error.\nSynonyms:\nparser_gleam/parser.cut\nparser_gleam/parser cut","url":"parser_gleam/parser.html#cut"},{"doc":"parser_gleam/parser","title":"cut_with","content":"pub fn cut_with(p1: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a)), p2: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, c), ParseError(a))) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, c), ParseError(a))\n Takes two parsers `p1` and `p2`, returning a parser which will match\n `p1` first, discard the result, then either match `p2` or produce a fatal\n error.\nSynonyms:\nparser_gleam/parser.cut_with\nparser_gleam/parser cut_with","url":"parser_gleam/parser.html#cut_with"},{"doc":"parser_gleam/parser","title":"either","content":"pub fn either(p: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a)), f: fn() -&gt;\n    fn(Stream(a)) -&gt; Result(ParseSuccess(a, b), ParseError(a))) -&gt; fn(\n  Stream(a),\n) -&gt; Result(ParseSuccess(a, b), ParseError(a))\n The `either` combinator takes two parsers, runs the first on the input\n stream, and if that fails, it will backtrack and attempt the second\n parser on the same input. Basically, try parser 1, then try parser 2.\n\n If the first parser fails with an error flagged as fatal (see `cut`),\n the second parser will not be attempted.\n\n This is equivalent to the `alt` operation.\nSynonyms:\nparser_gleam/parser.either\nparser_gleam/parser either","url":"parser_gleam/parser.html#either"},{"doc":"parser_gleam/parser","title":"eof","content":"pub fn eof() -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, Nil), ParseError(a))\n Matches the end of the stream.\nSynonyms:\nparser_gleam/parser.eof\nparser_gleam/parser eof","url":"parser_gleam/parser.html#eof"},{"doc":"parser_gleam/parser","title":"expected","content":"pub fn expected(p: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a)), message: String) -&gt; fn(\n  Stream(a),\n) -&gt; Result(ParseSuccess(a, b), ParseError(a))\n A parser combinator which returns the provided parser unchanged, except\n that if it fails, the provided error message will be returned in the\n ParseError`.\nSynonyms:\nparser_gleam/parser.expected\nparser_gleam/parser expected","url":"parser_gleam/parser.html#expected"},{"doc":"parser_gleam/parser","title":"fail","content":"pub fn fail() -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, b), ParseError(a))\n The `fail` parser will just fail immediately without consuming any input\nSynonyms:\nparser_gleam/parser.fail\nparser_gleam/parser fail","url":"parser_gleam/parser.html#fail"},{"doc":"parser_gleam/parser","title":"fail_at","content":"pub fn fail_at(i: Stream(a)) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, b), ParseError(a))\n The `failAt` parser will fail immediately without consuming any input,\n but will report the failure at the provided input position.\nSynonyms:\nparser_gleam/parser.fail_at\nparser_gleam/parser fail_at","url":"parser_gleam/parser.html#fail_at"},{"doc":"parser_gleam/parser","title":"filter","content":"pub fn filter(predicate: fn(a) -&gt; Bool) -&gt; fn(\n  fn(Stream(b)) -&gt; Result(ParseSuccess(b, a), ParseError(b)),\n) -&gt; fn(Stream(b)) -&gt; Result(ParseSuccess(b, a), ParseError(b))\n Filters the result of a parser based upon a `Refinement` or a `Predicate`.\n\nSynonyms:\nparser_gleam/parser.filter\nparser_gleam/parser filter","url":"parser_gleam/parser.html#filter"},{"doc":"parser_gleam/parser","title":"flatten","content":"pub fn flatten(mma: fn(Stream(a)) -&gt;\n    Result(\n      ParseSuccess(\n        a,\n        fn(Stream(a)) -&gt;\n          Result(ParseSuccess(a, b), ParseError(a)),\n      ),\n      ParseError(a),\n    )) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, b), ParseError(a))\n\nSynonyms:\nparser_gleam/parser.flatten\nparser_gleam/parser flatten","url":"parser_gleam/parser.html#flatten"},{"doc":"parser_gleam/parser","title":"get_monoid","content":"pub fn get_monoid(m: Monoid(a)) -&gt; Monoid(\n  fn(Stream(b)) -&gt; Result(ParseSuccess(b, a), ParseError(b)),\n)\n\nSynonyms:\nparser_gleam/parser.get_monoid\nparser_gleam/parser get_monoid","url":"parser_gleam/parser.html#get_monoid"},{"doc":"parser_gleam/parser","title":"get_semigroup","content":"pub fn get_semigroup(s: Semigroup(a)) -&gt; Semigroup(\n  fn(Stream(b)) -&gt; Result(ParseSuccess(b, a), ParseError(b)),\n)\n\nSynonyms:\nparser_gleam/parser.get_semigroup\nparser_gleam/parser get_semigroup","url":"parser_gleam/parser.html#get_semigroup"},{"doc":"parser_gleam/parser","title":"item","content":"pub fn item() -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, a), ParseError(a))\n The `item` parser consumes a single value, regardless of what it is,\n and returns it as its result.\nSynonyms:\nparser_gleam/parser.item\nparser_gleam/parser item","url":"parser_gleam/parser.html#item"},{"doc":"parser_gleam/parser","title":"look_ahead","content":"pub fn look_ahead(p: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a))) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, b), ParseError(a))\n Takes a `Parser` and tries to match it without consuming any input.\n\nSynonyms:\nparser_gleam/parser.look_ahead\nparser_gleam/parser look_ahead","url":"parser_gleam/parser.html#look_ahead"},{"doc":"parser_gleam/parser","title":"many","content":"pub fn many(p: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a))) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, List(b)), ParseError(a))\n The `many` combinator takes a parser, and returns a new parser which will\n run the parser repeatedly on the input stream until it fails, returning\n a list of the result values of each parse operation as its result, or the\n empty list if the parser never succeeded.\n\n Read that as &quot;match this parser zero or more times and give me a list of\n the results.&quot;\nSynonyms:\nparser_gleam/parser.many\nparser_gleam/parser many","url":"parser_gleam/parser.html#many"},{"doc":"parser_gleam/parser","title":"many1","content":"pub fn many1(parser: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a))) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, NonEmptyList(b)), ParseError(a))\n The `many1` combinator is just like the `many` combinator, except it\n requires its wrapped parser to match at least once. The resulting list is\n thus guaranteed to contain at least one value.\nSynonyms:\nparser_gleam/parser.many1\nparser_gleam/parser many1","url":"parser_gleam/parser.html#many1"},{"doc":"parser_gleam/parser","title":"many1_till","content":"pub fn many1_till(parser: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a)), terminator: fn(\n    Stream(a),\n  ) -&gt; Result(ParseSuccess(a, c), ParseError(a))) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, NonEmptyList(b)), ParseError(a))\n The `many1Till` combinator is just like the `manyTill` combinator, except it\n requires the value `parser` to match at least once before the `terminator`\n parser. The resulting list is thus guaranteed to contain at least one value.\n\nSynonyms:\nparser_gleam/parser.many1_till\nparser_gleam/parser many1_till","url":"parser_gleam/parser.html#many1_till"},{"doc":"parser_gleam/parser","title":"many_till","content":"pub fn many_till(parser: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a)), terminator: fn(\n    Stream(a),\n  ) -&gt; Result(ParseSuccess(a, c), ParseError(a))) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, List(b)), ParseError(a))\n The `manyTill` combinator takes a value `parser` and a `terminator` parser, and\n returns a new parser that will run the value `parser` repeatedly on the input\n stream, returning a list of the result values of each parse operation as its\n result, or the empty list if the parser never succeeded.\n\nSynonyms:\nparser_gleam/parser.many_till\nparser_gleam/parser many_till","url":"parser_gleam/parser.html#many_till"},{"doc":"parser_gleam/parser","title":"map","content":"pub fn map(ma: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a)), f: fn(b) -&gt; c) -&gt; fn(\n  Stream(a),\n) -&gt; Result(ParseSuccess(a, c), ParseError(a))\n\nSynonyms:\nparser_gleam/parser.map\nparser_gleam/parser map","url":"parser_gleam/parser.html#map"},{"doc":"parser_gleam/parser","title":"maybe","content":"pub fn maybe(m: Monoid(a)) -&gt; fn(\n  fn(Stream(b)) -&gt; Result(ParseSuccess(b, a), ParseError(b)),\n) -&gt; fn(Stream(b)) -&gt; Result(ParseSuccess(b, a), ParseError(b))\n The `maybe` parser combinator creates a parser which will run the provided\n parser on the input, and if it fails, it will returns the empty value (as\n defined by `empty`) as a result, without consuming any input.\nSynonyms:\nparser_gleam/parser.maybe\nparser_gleam/parser maybe","url":"parser_gleam/parser.html#maybe"},{"doc":"parser_gleam/parser","title":"of","content":"pub fn of(a: a) -&gt; fn(Stream(b)) -&gt;\n  Result(ParseSuccess(b, a), ParseError(b))\n\nSynonyms:\nparser_gleam/parser.of\nparser_gleam/parser of","url":"parser_gleam/parser.html#of"},{"doc":"parser_gleam/parser","title":"optional","content":"pub fn optional(parser: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a))) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, Option(b)), ParseError(a))\n Returns `Some&lt;A&gt;` if the specified parser succeeds, otherwise returns `None`.\n\nSynonyms:\nparser_gleam/parser.optional\nparser_gleam/parser optional","url":"parser_gleam/parser.html#optional"},{"doc":"parser_gleam/parser","title":"sat","content":"pub fn sat(predicate: fn(a) -&gt; Bool) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, a), ParseError(a))\n The `sat` parser constructor takes a predicate function, and will consume\n a single character if calling that predicate function with the character\n as its argument returns `true`. If it returns `false`, the parser will\n fail.\nSynonyms:\nparser_gleam/parser.sat\nparser_gleam/parser sat","url":"parser_gleam/parser.html#sat"},{"doc":"parser_gleam/parser","title":"sep_by","content":"pub fn sep_by(sep: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a)), p: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, c), ParseError(a))) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, List(c)), ParseError(a))\n Matches the provided parser `p` zero or more times, but requires the\n parser `sep` to match once in between each match of `p`. In other words,\n use `sep` to match separator characters in between matches of `p`.\nSynonyms:\nparser_gleam/parser.sep_by\nparser_gleam/parser sep_by","url":"parser_gleam/parser.html#sep_by"},{"doc":"parser_gleam/parser","title":"sep_by1","content":"pub fn sep_by1(sep: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a)), p: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, c), ParseError(a))) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, NonEmptyList(c)), ParseError(a))\n Matches the provided parser `p` one or more times, but requires the\n parser `sep` to match once in between each match of `p`. In other words,\n use `sep` to match separator characters in between matches of `p`.\nSynonyms:\nparser_gleam/parser.sep_by1\nparser_gleam/parser sep_by1","url":"parser_gleam/parser.html#sep_by1"},{"doc":"parser_gleam/parser","title":"sep_by_cut","content":"pub fn sep_by_cut(sep: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a)), p: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, c), ParseError(a))) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, NonEmptyList(c)), ParseError(a))\n Like `sepBy1`, but cut on the separator, so that matching a `sep` not\n followed by a `p` will cause a fatal error.\nSynonyms:\nparser_gleam/parser.sep_by_cut\nparser_gleam/parser sep_by_cut","url":"parser_gleam/parser.html#sep_by_cut"},{"doc":"parser_gleam/parser","title":"seq","content":"pub fn seq(fa: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a)), f: fn(b) -&gt;\n    fn(Stream(a)) -&gt; Result(ParseSuccess(a, c), ParseError(a))) -&gt; fn(\n  Stream(a),\n) -&gt; Result(ParseSuccess(a, c), ParseError(a))\n The `seq` combinator takes a parser, and a function which will receive\n the result of that parser if it succeeds, and which should return another\n parser, which will be run immediately after the initial parser. In this\n way, you can join parsers together in a sequence, producing more complex\n parsers.\n\n This is equivalent to the monadic `chain` operation.\nSynonyms:\nparser_gleam/parser.seq\nparser_gleam/parser seq","url":"parser_gleam/parser.html#seq"},{"doc":"parser_gleam/parser","title":"succeed","content":"pub fn succeed(a: a) -&gt; fn(Stream(b)) -&gt;\n  Result(ParseSuccess(b, a), ParseError(b))\n The `succeed` parser constructor creates a parser which will simply\n return the value provided as its argument, without consuming any input.\n\n This is equivalent to the monadic `of`.\nSynonyms:\nparser_gleam/parser.succeed\nparser_gleam/parser succeed","url":"parser_gleam/parser.html#succeed"},{"doc":"parser_gleam/parser","title":"surrounded_by","content":"pub fn surrounded_by(bound: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a))) -&gt; fn(\n  fn(Stream(a)) -&gt; Result(ParseSuccess(a, c), ParseError(a)),\n) -&gt; fn(Stream(a)) -&gt; Result(ParseSuccess(a, c), ParseError(a))\n Matches the provided parser `p` that is surrounded by the `bound` parser. Shortcut for `between(bound, bound)`.\nSynonyms:\nparser_gleam/parser.surrounded_by\nparser_gleam/parser surrounded_by","url":"parser_gleam/parser.html#surrounded_by"},{"doc":"parser_gleam/parser","title":"take_until","content":"pub fn take_until(predicate: fn(a) -&gt; Bool) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, List(a)), ParseError(a))\n Takes a `Predicate` and continues parsing until the given `Predicate` is satisfied.\n\nSynonyms:\nparser_gleam/parser.take_until\nparser_gleam/parser take_until","url":"parser_gleam/parser.html#take_until"},{"doc":"parser_gleam/parser","title":"with_start","content":"pub fn with_start(p: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, b), ParseError(a))) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, #(b, Stream(a))), ParseError(a))\n Converts a parser into one which will return the point in the stream where\n it started parsing in addition to its parsed value.\n\n Useful if you want to keep track of where in the input stream a parsed\n token came from.\nSynonyms:\nparser_gleam/parser.with_start\nparser_gleam/parser with_start","url":"parser_gleam/parser.html#with_start"},{"doc":"parser_gleam/parser","title":"zero","content":"pub fn zero() -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, b), ParseError(a))\n\nSynonyms:\nparser_gleam/parser.zero\nparser_gleam/parser zero","url":"parser_gleam/parser.html#zero"},{"doc":"parser_gleam/parser","title":"parser_gleam/parser","content":"","url":"parser_gleam/parser.html"},{"doc":"parser_gleam/char","title":"Char","content":"pub type Char =\n  String\n\n\nSynonyms:\nparser_gleam/char.Char\nparser_gleam/char Char","url":"parser_gleam/char.html#Char"},{"doc":"parser_gleam/char","title":"alphanum","content":"pub fn alphanum() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches a single letter, digit or underscore character.\nSynonyms:\nparser_gleam/char.alphanum\nparser_gleam/char alphanum","url":"parser_gleam/char.html#alphanum"},{"doc":"parser_gleam/char","title":"char","content":"pub fn char(c: String) -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n The `char` parser constructor returns a parser which matches only the\n specified single character\nSynonyms:\nparser_gleam/char.char\nparser_gleam/char char","url":"parser_gleam/char.html#char"},{"doc":"parser_gleam/char","title":"digit","content":"pub fn digit() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches a single digit.\nSynonyms:\nparser_gleam/char.digit\nparser_gleam/char digit","url":"parser_gleam/char.html#digit"},{"doc":"parser_gleam/char","title":"letter","content":"pub fn letter() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches a single ASCII letter.\nSynonyms:\nparser_gleam/char.letter\nparser_gleam/char letter","url":"parser_gleam/char.html#letter"},{"doc":"parser_gleam/char","title":"lower","content":"pub fn lower() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches a single lower case ASCII letter.\nSynonyms:\nparser_gleam/char.lower\nparser_gleam/char lower","url":"parser_gleam/char.html#lower"},{"doc":"parser_gleam/char","title":"many","content":"pub fn many(parser: fn(Stream(String)) -&gt;\n    Result(ParseSuccess(String, String), ParseError(String))) -&gt; fn(\n  Stream(String),\n) -&gt; Result(ParseSuccess(String, String), ParseError(String))\n Takes a `Parser&lt;Char, string&gt;` and matches it zero or more times, returning\n a `string` of what was matched.\nSynonyms:\nparser_gleam/char.many\nparser_gleam/char many","url":"parser_gleam/char.html#many"},{"doc":"parser_gleam/char","title":"many1","content":"pub fn many1(parser: fn(Stream(String)) -&gt;\n    Result(ParseSuccess(String, String), ParseError(String))) -&gt; fn(\n  Stream(String),\n) -&gt; Result(ParseSuccess(String, String), ParseError(String))\n Takes a `Parser&lt;Char, string&gt;` and matches it one or more times, returning\n a `string` of what was matched.\nSynonyms:\nparser_gleam/char.many1\nparser_gleam/char many1","url":"parser_gleam/char.html#many1"},{"doc":"parser_gleam/char","title":"not_alphanum","content":"pub fn not_alphanum() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches a single character which isn&#39;t a letter, digit or underscore.\nSynonyms:\nparser_gleam/char.not_alphanum\nparser_gleam/char not_alphanum","url":"parser_gleam/char.html#not_alphanum"},{"doc":"parser_gleam/char","title":"not_char","content":"pub fn not_char(c: String) -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n The `notChar` parser constructor makes a parser which will match any\n single character other than the one provided.\nSynonyms:\nparser_gleam/char.not_char\nparser_gleam/char not_char","url":"parser_gleam/char.html#not_char"},{"doc":"parser_gleam/char","title":"not_digit","content":"pub fn not_digit() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches a single character which isn&#39;t a digit.\nSynonyms:\nparser_gleam/char.not_digit\nparser_gleam/char not_digit","url":"parser_gleam/char.html#not_digit"},{"doc":"parser_gleam/char","title":"not_letter","content":"pub fn not_letter() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches a single character which isn&#39;t an upper case ASCII letter.\nSynonyms:\nparser_gleam/char.not_letter\nparser_gleam/char not_letter","url":"parser_gleam/char.html#not_letter"},{"doc":"parser_gleam/char","title":"not_lower","content":"pub fn not_lower() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches a single character which isn&#39;t a lower case ASCII letter.\nSynonyms:\nparser_gleam/char.not_lower\nparser_gleam/char not_lower","url":"parser_gleam/char.html#not_lower"},{"doc":"parser_gleam/char","title":"not_one_of","content":"pub fn not_one_of(s: String) -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches a single character which isn&#39;t a character from the provided string.\nSynonyms:\nparser_gleam/char.not_one_of\nparser_gleam/char not_one_of","url":"parser_gleam/char.html#not_one_of"},{"doc":"parser_gleam/char","title":"not_space","content":"pub fn not_space() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches a single character which isn&#39;t whitespace.\nSynonyms:\nparser_gleam/char.not_space\nparser_gleam/char not_space","url":"parser_gleam/char.html#not_space"},{"doc":"parser_gleam/char","title":"not_upper","content":"pub fn not_upper() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches a single character which isn&#39;t an upper case ASCII letter.\nSynonyms:\nparser_gleam/char.not_upper\nparser_gleam/char not_upper","url":"parser_gleam/char.html#not_upper"},{"doc":"parser_gleam/char","title":"one_of","content":"pub fn one_of(s: String) -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches any one character from the provided string.\nSynonyms:\nparser_gleam/char.one_of\nparser_gleam/char one_of","url":"parser_gleam/char.html#one_of"},{"doc":"parser_gleam/char","title":"space","content":"pub fn space() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches a single whitespace character.\nSynonyms:\nparser_gleam/char.space\nparser_gleam/char space","url":"parser_gleam/char.html#space"},{"doc":"parser_gleam/char","title":"unicode_letter","content":"pub fn unicode_letter() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches a single Unicode letter.\n Works for scripts which have a notion of an upper case and lower case letters\n (Latin-based scripts, Greek, Russian etc).\nSynonyms:\nparser_gleam/char.unicode_letter\nparser_gleam/char unicode_letter","url":"parser_gleam/char.html#unicode_letter"},{"doc":"parser_gleam/char","title":"upper","content":"pub fn upper() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches a single upper case ASCII letter.\nSynonyms:\nparser_gleam/char.upper\nparser_gleam/char upper","url":"parser_gleam/char.html#upper"},{"doc":"parser_gleam/char","title":"parser_gleam/char","content":"","url":"parser_gleam/char.html"},{"doc":"parser_gleam/string","title":"double_quoted_string","content":"pub fn double_quoted_string() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Parses a double quoted string, with support for escaping double quotes\n inside it, and returns the inner string. Does not perform any other form\n of string escaping.\nSynonyms:\nparser_gleam/string.double_quoted_string\nparser_gleam/string double_quoted_string","url":"parser_gleam/string.html#double_quoted_string"},{"doc":"parser_gleam/string","title":"float","content":"pub fn float() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, Float), ParseError(String))\n\nSynonyms:\nparser_gleam/string.float\nparser_gleam/string float","url":"parser_gleam/string.html#float"},{"doc":"parser_gleam/string","title":"fold","content":"pub fn fold(ass: List(\n    fn(Stream(a)) -&gt;\n      Result(ParseSuccess(a, String), ParseError(a)),\n  )) -&gt; fn(Stream(a)) -&gt;\n  Result(ParseSuccess(a, String), ParseError(a))\n Matches one of a list of strings.\nSynonyms:\nparser_gleam/string.fold\nparser_gleam/string fold","url":"parser_gleam/string.html#fold"},{"doc":"parser_gleam/string","title":"int","content":"pub fn int() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, Int), ParseError(String))\n\nSynonyms:\nparser_gleam/string.int\nparser_gleam/string int","url":"parser_gleam/string.html#int"},{"doc":"parser_gleam/string","title":"many","content":"pub fn many(parser: fn(Stream(String)) -&gt;\n    Result(ParseSuccess(String, String), ParseError(String))) -&gt; fn(\n  Stream(String),\n) -&gt; Result(ParseSuccess(String, String), ParseError(String))\n Matches the given parser zero or more times, returning a string of the\n entire match\nSynonyms:\nparser_gleam/string.many\nparser_gleam/string many","url":"parser_gleam/string.html#many"},{"doc":"parser_gleam/string","title":"many1","content":"pub fn many1(parser: fn(Stream(String)) -&gt;\n    Result(ParseSuccess(String, String), ParseError(String))) -&gt; fn(\n  Stream(String),\n) -&gt; Result(ParseSuccess(String, String), ParseError(String))\n Matches the given parser zero or more times, returning a string of the\n entire match\nSynonyms:\nparser_gleam/string.many1\nparser_gleam/string many1","url":"parser_gleam/string.html#many1"},{"doc":"parser_gleam/string","title":"maybe","content":"pub fn maybe(p: fn(Stream(a)) -&gt;\n    Result(ParseSuccess(a, String), ParseError(a))) -&gt; fn(\n  Stream(a),\n) -&gt; Result(ParseSuccess(a, String), ParseError(a))\n\nSynonyms:\nparser_gleam/string.maybe\nparser_gleam/string maybe","url":"parser_gleam/string.html#maybe"},{"doc":"parser_gleam/string","title":"not_spaces","content":"pub fn not_spaces() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches zero or more non-whitespace characters.\nSynonyms:\nparser_gleam/string.not_spaces\nparser_gleam/string not_spaces","url":"parser_gleam/string.html#not_spaces"},{"doc":"parser_gleam/string","title":"not_spaces1","content":"pub fn not_spaces1() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches one or more non-whitespace characters.\nSynonyms:\nparser_gleam/string.not_spaces1\nparser_gleam/string not_spaces1","url":"parser_gleam/string.html#not_spaces1"},{"doc":"parser_gleam/string","title":"one_of","content":"pub fn one_of(lst: List(String)) -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n\nSynonyms:\nparser_gleam/string.one_of\nparser_gleam/string one_of","url":"parser_gleam/string.html#one_of"},{"doc":"parser_gleam/string","title":"run","content":"pub fn run(str: String) -&gt; fn(\n  fn(Stream(String)) -&gt;\n    Result(ParseSuccess(String, a), ParseError(String)),\n) -&gt; Result(ParseSuccess(String, a), ParseError(String))\n Creates a stream from `string` and runs the parser.\nSynonyms:\nparser_gleam/string.run\nparser_gleam/string run","url":"parser_gleam/string.html#run"},{"doc":"parser_gleam/string","title":"spaces","content":"pub fn spaces() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches zero or more whitespace characters.\nSynonyms:\nparser_gleam/string.spaces\nparser_gleam/string spaces","url":"parser_gleam/string.html#spaces"},{"doc":"parser_gleam/string","title":"spaces1","content":"pub fn spaces1() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches one or more whitespace characters.\nSynonyms:\nparser_gleam/string.spaces1\nparser_gleam/string spaces1","url":"parser_gleam/string.html#spaces1"},{"doc":"parser_gleam/string","title":"string","content":"pub fn string(s: String) -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, String), ParseError(String))\n Matches the exact string provided.\nSynonyms:\nparser_gleam/string.string\nparser_gleam/string string","url":"parser_gleam/string.html#string"},{"doc":"parser_gleam/string","title":"parser_gleam/string","content":"","url":"parser_gleam/string.html"},{"doc":"examples/custom_type","title":"Ast","content":"pub type Ast =\n  List(AstNode)\n\n\nSynonyms:\nexamples/custom_type.Ast\nexamples/custom_type Ast","url":"examples/custom_type.html#Ast"},{"doc":"examples/custom_type","title":"AstNode","content":"pub type AstNode {\n  NodeIgnoredCode(it: IgnoredCode)\n  NodeXCustomType(it: XCustomType)\n}\n\nNodeIgnoredCode(it: IgnoredCode)\n\n\nNodeXCustomType(it: XCustomType)\n\n\nSynonyms:\nexamples/custom_type.AstNode\nexamples/custom_type AstNode","url":"examples/custom_type.html#AstNode"},{"doc":"examples/custom_type","title":"IgnoredCode","content":"pub type IgnoredCode {\n  IgnoredCode(content: String)\n}\n\nIgnoredCode(content: String)\n\n\nSynonyms:\nexamples/custom_type.IgnoredCode\nexamples/custom_type IgnoredCode","url":"examples/custom_type.html#IgnoredCode"},{"doc":"examples/custom_type","title":"RecordConstructor","content":"pub type RecordConstructor {\n  RecordConstructor(\n    name: String,\n    arguments: List(RecordConstructorArg),\n  )\n}\n\nRecordConstructor(\n  name: String,\n  arguments: List(RecordConstructorArg),\n)\n\n\nSynonyms:\nexamples/custom_type.RecordConstructor\nexamples/custom_type RecordConstructor","url":"examples/custom_type.html#RecordConstructor"},{"doc":"examples/custom_type","title":"RecordConstructorArg","content":"pub type RecordConstructorArg {\n  RecordConstructorArg(label: String, ast: TypeAst)\n}\n\nRecordConstructorArg(label: String, ast: TypeAst)\n\n\nSynonyms:\nexamples/custom_type.RecordConstructorArg\nexamples/custom_type RecordConstructorArg","url":"examples/custom_type.html#RecordConstructorArg"},{"doc":"examples/custom_type","title":"TypeAst","content":"pub type TypeAst {\n  Constructor(\n    module: Option(String),\n    name: String,\n    arguments: List(TypeAst),\n  )\n  Fn(arguments: List(TypeAst), return_: TypeAst)\n  Var(name: String)\n  Tuple(elems: List(TypeAst))\n  Hole(name: String)\n}\n\nConstructor(\n  module: Option(String),\n  name: String,\n  arguments: List(TypeAst),\n)\n\n\nFn(arguments: List(TypeAst), return_: TypeAst)\n\n\nVar(name: String)\n\n\nTuple(elems: List(TypeAst))\n\n\nHole(name: String)\n\n\nSynonyms:\nexamples/custom_type.TypeAst\nexamples/custom_type TypeAst","url":"examples/custom_type.html#TypeAst"},{"doc":"examples/custom_type","title":"XCustomType","content":"pub type XCustomType {\n  XCustomType(\n    name: String,\n    constructors: List(RecordConstructor),\n    parameters: List(String),\n  )\n}\n\nXCustomType(\n  name: String,\n  constructors: List(RecordConstructor),\n  parameters: List(String),\n)\n\n\nSynonyms:\nexamples/custom_type.XCustomType\nexamples/custom_type XCustomType","url":"examples/custom_type.html#XCustomType"},{"doc":"examples/custom_type","title":"ast_parser","content":"pub fn ast_parser() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, List(AstNode)), ParseError(String))\n\nSynonyms:\nexamples/custom_type.ast_parser\nexamples/custom_type ast_parser","url":"examples/custom_type.html#ast_parser"},{"doc":"examples/custom_type","title":"filter_custom_types","content":"pub fn filter_custom_types(ast: List(AstNode)) -&gt; List(\n  XCustomType,\n)\n\nSynonyms:\nexamples/custom_type.filter_custom_types\nexamples/custom_type filter_custom_types","url":"examples/custom_type.html#filter_custom_types"},{"doc":"examples/custom_type","title":"record_constructor_argument_parser","content":"pub fn record_constructor_argument_parser() -&gt; fn(Stream(String)) -&gt;\n  Result(\n    ParseSuccess(String, RecordConstructorArg),\n    ParseError(String),\n  )\n\nSynonyms:\nexamples/custom_type.record_constructor_argument_parser\nexamples/custom_type record_constructor_argument_parser","url":"examples/custom_type.html#record_constructor_argument_parser"},{"doc":"examples/custom_type","title":"record_constructor_parser","content":"pub fn record_constructor_parser() -&gt; fn(Stream(String)) -&gt;\n  Result(\n    ParseSuccess(String, RecordConstructor),\n    ParseError(String),\n  )\n\nSynonyms:\nexamples/custom_type.record_constructor_parser\nexamples/custom_type record_constructor_parser","url":"examples/custom_type.html#record_constructor_parser"},{"doc":"examples/custom_type","title":"examples/custom_type","content":"","url":"examples/custom_type.html"},{"doc":"examples/info_string","title":"Argument","content":"pub type Argument {\n  ArgumentFlag(Flag)\n  ArgumentNamed(Named)\n}\n\nArgumentFlag(Flag)\n\n\nArgumentNamed(Named)\n\n\nSynonyms:\nexamples/info_string.Argument\nexamples/info_string Argument","url":"examples/info_string.html#Argument"},{"doc":"examples/info_string","title":"EvalInfoString","content":"pub type EvalInfoString {\n  EvalInfoString(\n    language: String,\n    flags: List(Flag),\n    named: List(Named),\n  )\n}\n\nEvalInfoString(\n  language: String,\n  flags: List(Flag),\n  named: List(Named),\n)\n\n\nSynonyms:\nexamples/info_string.EvalInfoString\nexamples/info_string EvalInfoString","url":"examples/info_string.html#EvalInfoString"},{"doc":"examples/info_string","title":"Flag","content":"pub type Flag {\n  Flag(value: String)\n}\n\nFlag(value: String)\n\n\nSynonyms:\nexamples/info_string.Flag\nexamples/info_string Flag","url":"examples/info_string.html#Flag"},{"doc":"examples/info_string","title":"Named","content":"pub type Named {\n  Named(name: String, value: String)\n}\n\nNamed(name: String, value: String)\n\n\nSynonyms:\nexamples/info_string.Named\nexamples/info_string Named","url":"examples/info_string.html#Named"},{"doc":"examples/info_string","title":"get_language","content":"pub fn get_language(info_string: String) -&gt; Option(String)\n\nSynonyms:\nexamples/info_string.get_language\nexamples/info_string get_language","url":"examples/info_string.html#get_language"},{"doc":"examples/info_string","title":"info_string_parser","content":"pub fn info_string_parser() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, EvalInfoString), ParseError(String))\n\nSynonyms:\nexamples/info_string.info_string_parser\nexamples/info_string info_string_parser","url":"examples/info_string.html#info_string_parser"},{"doc":"examples/info_string","title":"is_eval","content":"pub fn is_eval(info_string: String) -&gt; Bool\n\nSynonyms:\nexamples/info_string.is_eval\nexamples/info_string is_eval","url":"examples/info_string.html#is_eval"},{"doc":"examples/info_string","title":"language_parser","content":"pub fn language_parser() -&gt; fn(Stream(String)) -&gt;\n  Result(ParseSuccess(String, Option(String)), ParseError(String))\n\nSynonyms:\nexamples/info_string.language_parser\nexamples/info_string language_parser","url":"examples/info_string.html#language_parser"},{"doc":"examples/info_string","title":"parse","content":"pub fn parse(info_string: String) -&gt; Result(\n  ParseSuccess(String, EvalInfoString),\n  ParseError(String),\n)\n\nSynonyms:\nexamples/info_string.parse\nexamples/info_string parse","url":"examples/info_string.html#parse"},{"doc":"examples/info_string","title":"examples/info_string","content":"","url":"examples/info_string.html"}]);